import { View } from '@tarojs/components';
import Taro from '@tarojs/taro';
import cx from 'classnames';
import React, { useCallback, useEffect, useMemo, useRef, useState } from 'react';
import HuiIcon from '../Icon';
import HuiText from '../Text/Text';
const defaultChildPadding = 16;
const prefix = 'hui-collapse';
const CollapsePanel = (props) => {
    const { title = '折叠面板', name = Date.now(), active = true, disabled = false, expandText = null, expandIcon = React.createElement(HuiIcon, { name: 'h011-downward' }), className = '', style = {}, children, } = props;
    const panelChildRef = useRef();
    const [visible, setVisible] = useState(active);
    const [height, setHeight] = useState(active ? 100 : 0);
    const childClassName = useMemo(() => `${prefix}-child-${name}`, [name]);
    const getHeight = useCallback(() => {
        const query = Taro.createSelectorQuery();
        if (!childClassName) {
            throw new Error('传入的Taro.TaroElement对象需要有className');
        }
        query
            .select(`.${childClassName}`)
            .fields({
            size: true,
            computedStyle: ['height', 'padding'],
            context: true,
        }, (res) => {
            var _a, _b;
            const resHeight = (_a = res === null || res === void 0 ? void 0 : res.height) === null || _a === void 0 ? void 0 : _a.replace('px', '');
            const resPadding = (_b = res === null || res === void 0 ? void 0 : res.padding) === null || _b === void 0 ? void 0 : _b.replace('px', '');
            setHeight((res === null || res === void 0 ? void 0 : res.height) ? +resHeight + +resPadding * 2 : 100);
        })
            .exec();
    }, [childClassName, visible]);
    useEffect(() => {
        if (visible) {
            Taro.nextTick(() => getHeight());
        }
        else {
            setHeight(0);
        }
    }, [visible, childClassName]);
    const panel = useMemo(() => (React.createElement(View, { className: cx(`${prefix}-child`, {
            [`${prefix}-child-active`]: visible,
        }), style: {
            height,
        } },
        React.createElement(View, { ref: panelChildRef, className: cx(`${childClassName}`, {
                [`${className}`]: Boolean(className),
            }), style: Object.assign({ padding: defaultChildPadding }, style) }, children))), [height, children, className, style, childClassName, visible]);
    const text = useMemo(() => {
        if (typeof expandText === 'function') {
            return React.createElement(HuiText, null, expandText(visible));
        }
        return React.createElement(HuiText, null, expandText !== null && expandText !== void 0 ? expandText : (!visible ? '展开' : '收起'));
    }, [visible, expandText]);
    const collapseIcon = useMemo(() => {
        if (typeof expandIcon === 'function') {
            return React.createElement(View, { className: 'icon' }, expandIcon(visible));
        }
        return (React.createElement(View, { className: cx('icon', {
                upward: visible,
                downward: !visible,
            }) }, expandIcon));
    }, [visible, expandIcon]);
    return (React.createElement(View, { className: `${prefix}` },
        React.createElement(View, { className: cx(`${prefix}-header`, {
                [`${prefix}-header-disabled`]: disabled,
            }), onClick: () => {
                if (disabled)
                    return;
                setVisible(!visible);
            } },
            React.createElement(HuiText, { className: `${prefix}-header-title` }, title),
            React.createElement(View, { className: `${prefix}-header-toggle` },
                text,
                collapseIcon)),
        panel));
};
export default CollapsePanel;
//# sourceMappingURL=CollapsePanel.js.map