var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React, { useState, useRef, useImperativeHandle, forwardRef, useContext, useMemo, } from 'react';
import { View } from '@tarojs/components';
import cx from 'classnames';
import MenuItem from '../MenuItem/MenuItem';
import HuiIcon from '../../Icon';
import { generateUniqueId } from '../utils';
import FilterContext from '../context';
const defaultProps = {
    className: '',
    style: {},
};
const InternalMenu = forwardRef((props, ref) => {
    const { menuOnChange, onMenuTitleClick, className, children } = props, rest = __rest(props, ["menuOnChange", "onMenuTitleClick", "className", "children"]);
    const menuRef = useRef();
    const [activatedList, setActivatedList] = useState([]);
    const [menuItemTitle, setMenuItemTitle] = useState([]);
    const context = useContext(FilterContext);
    const toggleMenuItem = (index, disabled, e) => {
        if (disabled)
            return;
        const temp = [...activatedList];
        temp[index] = !temp[index];
        for (let i = 0; i < temp.length; i++) {
            temp[i] = i === index ? temp[i] : false;
        }
        setActivatedList(temp);
        onMenuTitleClick && onMenuTitleClick(e, index, temp.includes(true));
        context === null || context === void 0 ? void 0 : context.hideFilter();
    };
    const hideMenuItem = (index) => {
        const temp = [...activatedList];
        temp[index] = false;
        setActivatedList(temp);
    };
    useImperativeHandle(ref, () => ({
        hide: () => {
            setActivatedList([]);
        },
    }));
    const updateMenuItemTitle = (index, text) => {
        const temp = [...menuItemTitle];
        temp[index] = text;
        setMenuItemTitle(temp);
    };
    const renderMenuTitle = () => React.Children.map(children, (child, index) => {
        if (React.isValidElement(child)) {
            const { title, options, value, icon, disabled } = child.props;
            const selected = options === null || options === void 0 ? void 0 : options.filter((item) => item.value === value);
            const getTitle = () => {
                var _a;
                if (title)
                    return title;
                if (menuItemTitle[index]) {
                    return menuItemTitle[index];
                }
                return (_a = selected === null || selected === void 0 ? void 0 : selected[0]) === null || _a === void 0 ? void 0 : _a.text;
            };
            const clipText = (text) => {
                if (text.length > 6) {
                    return `${text.substring(0, 6)}...`;
                }
                else {
                    return text;
                }
            };
            return (React.createElement(View, { className: cx('hui-filter-menu-item', {
                    active: activatedList[index],
                    disabled,
                }), onClick: (e) => toggleMenuItem(index, disabled, e) },
                React.createElement(View, { className: 'hui-filter-menu-item-text' }, clipText(getTitle())),
                icon || (React.createElement(View, { className: 'hui-filter-menu-item-icon' },
                    React.createElement(HuiIcon, { name: 'h110-upwards', size: 14 })))));
        }
        return null;
    });
    const renderMenuItem = useMemo(() => React.Children.map(children, (child, index) => {
        if (React.isValidElement(child)) {
            return React.cloneElement(child, {
                parent: {
                    index,
                    show: activatedList[index],
                    menuRef,
                    hideMenuItem,
                    updateMenuItemTitle,
                    menuOnChange,
                    filterTop: context.filterTop,
                },
            });
        }
        return null;
    }), [
        activatedList,
        menuRef,
        hideMenuItem,
        updateMenuItemTitle,
        menuOnChange,
        context.filterTop,
    ]);
    return (React.createElement(View, Object.assign({}, rest, { className: cx('hui-filter-menu', className, generateUniqueId()), ref: menuRef }),
        React.createElement(View, { className: 'hui-filter-menu-bar' }, renderMenuTitle()),
        renderMenuItem));
});
InternalMenu.defaultProps = defaultProps;
const Menu = InternalMenu;
Menu.Item = MenuItem;
export default Menu;
//# sourceMappingURL=Menu.js.map