import { View } from '@tarojs/components';
import { usePageScroll } from '@tarojs/taro';
import cx from 'classnames';
import React, { useImperativeHandle, useMemo, } from 'react';
import Popup from '../../Popup';
import ActionFooter from '../ActionFooter/ActionFooter';
const defaultProps = {
    className: '',
    style: {},
    columns: 1,
};
const MenuItem = React.forwardRef((props, ref) => {
    const { title, options, columns, onChange, className, style, parent, children, footer, onMaskClose, } = props;
    const position = useMemo(() => {
        if (parent.filterTop) {
            return {
                top: parent.filterTop,
            };
        }
        return {};
    }, [parent]);
    useImperativeHandle(ref, () => ({ hideMenu }));
    usePageScroll(() => {
        if (parent.show)
            hideMenu();
    });
    const hideMenu = () => {
        parent.hideMenuItem(parent.index);
    };
    const updateTitle = (text) => {
        if (!title) {
            parent.updateMenuItemTitle(parent.index, text);
        }
    };
    const handleClick = (item) => {
        hideMenu();
        updateTitle(item.text);
        onChange && onChange(item);
        parent.menuOnChange && parent.menuOnChange(item);
    };
    const renderOptions = () => {
        if (options) {
            return options.map((item, index) => (React.createElement(View, { className: 'hui-filter-menu-item-option', key: index, onClick: () => handleClick(item), style: { flexBasis: `${100 / columns}%` } }, item.text)));
        }
        return null;
    };
    const renderChildren = () => {
        if (typeof children === 'function') {
            return children({ hideMenu });
        }
        return children;
    };
    const actionFooterProps = {
        confirmButtonProps: props.confirmButtonProps,
        clearButtonProps: props.clearButtonProps,
        confirmText: props.confirmText,
        clearText: props.clearText,
        onConfirm: props.onConfirm,
        onClear: props.onClear,
        hideMenu,
    };
    return (React.createElement(Popup, { visible: parent.show, position: 'top', maskStyle: position, contentStyle: position, onClose: () => {
            hideMenu();
            onMaskClose && onMaskClose();
        }, className: cx('hui-filter-animation', {
            'no-animation': !parent.show,
        }) },
        React.createElement(View, { className: cx(className), style: Object.assign({}, style) },
            React.createElement(View, { className: cx('hui-filter-menu-item-content', {
                    'is-footer': options,
                }) }, !options ? renderChildren() : renderOptions()),
            footer && React.createElement(ActionFooter, Object.assign({}, actionFooterProps)))));
});
MenuItem.defaultProps = defaultProps;
export default MenuItem;
//# sourceMappingURL=MenuItem.js.map