import { Form } from '@tarojs/components';
import React, { useCallback, useEffect, useImperativeHandle, } from 'react';
import classNames from 'classnames';
import Context from './constants';
import useForm from './hooks/useForm';
const defaultFunc = () => ({});
const { Provider } = Context;
const HuiForm = (props, ref) => {
    const { onFinish = defaultFunc, onValuesChange = defaultFunc, onFinishFailed = defaultFunc, onReset = defaultFunc, children, form, className, } = props;
    const formInstance = useForm(form)[0];
    const { setCallbacks, submit, reset } = formInstance;
    const handleSubmit = useCallback((event) => {
        event.preventDefault();
        event.stopPropagation();
        submit();
    }, [submit]);
    const handleReset = useCallback((event) => {
        event.preventDefault();
        event.stopPropagation();
        reset();
    }, [reset]);
    useEffect(() => {
        setCallbacks({
            onFinish,
            onFinishFailed,
            onValuesChange,
            onReset,
        });
        return () => setCallbacks({
            onFinish: defaultFunc,
            onFinishFailed: defaultFunc,
            onValuesChange: defaultFunc,
            onReset: defaultFunc,
        });
    }, [onFinish, onFinishFailed, onReset, onValuesChange, setCallbacks]);
    useImperativeHandle(ref, () => formInstance, []);
    return (React.createElement(Form, { className: classNames('hui-form', className), onSubmit: handleSubmit, onReset: handleReset },
        React.createElement(Provider, { value: formInstance }, children)));
};
/**
 * form表单容器组件
 */
const HForm = React.forwardRef(HuiForm);
export default HForm;
//# sourceMappingURL=Form.js.map