import { View, Text, Label } from '@tarojs/components';
import classNames from 'classnames';
import React, { useCallback, useContext, useEffect, useMemo, useRef, useState, } from 'react';
import HuiIcon from '../../Icon/Icon';
import { useAnimationCss } from './animation';
import validatorField from './rules';
import Context, { formItemPrefix, FormItemContext, NormalCss, FormListContext, AlignType, } from '../constants';
import { toArray } from '../util';
/**
 * form表单基础组件
 */
const Item = (props) => {
    const context = useContext(Context);
    const { registerWatch, getFieldValue, setFieldValue, removeFieldValue } = context;
    const listContext = useContext(FormListContext);
    const [renderType, setRenderType] = useState('other');
    const [, update] = useState({});
    const [submitTotal, setSubmitTotal] = useState(0);
    const [ruleCss, setRuleCss] = useState(NormalCss);
    const [ruleText, setRuleText] = useState();
    const newProps = useRef({});
    const { name, label, children, className = '', style, visible = true, 
    // desc,
    tipsText = '', labelStyle, rule = [], align = AlignType.ROW, customOptionalStyle = null, hiddenOptionalStyle = false, labelIconNode, onLabelIconClick, showArrow = false, extra = null, } = props;
    const { Provider } = FormItemContext;
    const [ruleTarget = {}] = rule;
    const { name: listName } = listContext;
    const path = useMemo(() => {
        const nameArr = toArray(name);
        if (listName)
            nameArr.unshift(listName);
        return nameArr;
    }, [name, listName]);
    const requireIcon = useMemo(() => !(ruleTarget === null || ruleTarget === void 0 ? void 0 : ruleTarget.require) && !hiddenOptionalStyle
        ? customOptionalStyle || (React.createElement(Text, { className: `${formItemPrefix}-option` }, "(\u9009\u586B)"))
        : null, [ruleTarget === null || ruleTarget === void 0 ? void 0 : ruleTarget.require, hiddenOptionalStyle, customOptionalStyle]);
    const labelIcon = useMemo(() => labelIconNode ? (React.createElement(View, { onClick: onLabelIconClick }, labelIconNode)) : null, [labelIconNode, onLabelIconClick]);
    const ruleErrorView = useMemo(() => ruleText ? (React.createElement(View, { className: `${formItemPrefix}-rule` }, ruleText)) : null, [ruleText]);
    const tipsView = useMemo(() => tipsText ? (React.createElement(View, { className: `${formItemPrefix}-tips` }, tipsText)) : null, [tipsText]);
    const localValue = getFieldValue(path);
    const onChange = useCallback((event) => {
        var _a, _b;
        setFieldValue(path, (_b = (_a = event === null || event === void 0 ? void 0 : event.detail) === null || _a === void 0 ? void 0 : _a.value) !== null && _b !== void 0 ? _b : event);
    }, [path, setFieldValue]);
    const copyChildren = () => {
        if (React.isValidElement(children)) {
            if (!children.props.onChange) {
                newProps.current.onChange = onChange;
            }
            else {
                delete newProps.current.onChange;
            }
            if (children.props.value === undefined) {
                newProps.current.value = localValue;
            }
            else {
                delete newProps.current.value;
            }
            return children && React.cloneElement(children, newProps.current);
        }
        return children;
    };
    const [implementAnimation] = useAnimationCss(`${formItemPrefix}-animation`, !!ruleText);
    const validatorRules = async (value) => {
        try {
            const [css, text] = validatorField(rule, value, renderType, getFieldValue);
            setRuleCss(css);
            setRuleText(text);
            return {
                state: !text,
                name: path,
            };
        }
        catch (error) {
            throw new Error(error);
        }
    };
    useEffect(() => {
        validatorRules(localValue);
    }, [localValue]);
    useEffect(() => {
        const unMount = registerWatch({
            name: path,
            setSubmitTotal,
            validatorRules,
            onStoreChange: () => update({}),
        });
        return () => {
            removeFieldValue(path);
            unMount();
        };
    }, [path, registerWatch]);
    useEffect(() => {
        if (submitTotal)
            implementAnimation();
    }, [submitTotal, implementAnimation]);
    if (!visible)
        return null;
    return (React.createElement(View, { className: classNames(formItemPrefix) },
        React.createElement(View, { className: classNames(`${formItemPrefix}-wrapper`, className, {
                [ruleCss]: renderType === 'other',
            }), style: Object.assign({}, style) },
            React.createElement(View, { className: classNames({
                    [`${formItemPrefix}-row`]: align === AlignType.ROW,
                    [`${formItemPrefix}-column`]: align === AlignType.COLUMN,
                }) },
                label && (React.createElement(View, { className: `${formItemPrefix}-text`, style: Object.assign({}, labelStyle) },
                    React.createElement(View, { className: `${formItemPrefix}-text-label` },
                        label,
                        requireIcon,
                        labelIcon))),
                React.createElement(Label, { className: `${formItemPrefix}-content` },
                    React.createElement(Provider, { value: {
                            setRenderType,
                        } }, copyChildren())),
                React.createElement(View, { className: `${formItemPrefix}-extra` },
                    React.createElement(View, null, extra),
                    showArrow && (React.createElement(View, null,
                        React.createElement(HuiIcon, { className: `${formItemPrefix}-arrow`, name: '012-right' }))))), ruleErrorView !== null && ruleErrorView !== void 0 ? ruleErrorView : tipsView)));
};
export default Item;
//# sourceMappingURL=index.js.map