import { replaceComma } from '../../util';
import { checkDigit, checkInteger } from './checkNumber';
import { errorCss, normalCss, validatorDigitText, validatorIntegerText, validatorRequireText, } from '../../constants/field';
/**
 * 内部校验
 */
const validatorInnerField = (value, itemType) => {
    switch (itemType) {
        case 'inputNumber':
            return checkInteger(replaceComma(value))[0];
        case 'inputDigit':
            return checkDigit(replaceComma(value))[0];
        default:
            return true;
    }
};
const validatorRule = (rule, value, fieldType, getFieldValue) => {
    const [defaultRuleTarget, customRuleFun] = rule || [];
    const { require, pattern } = defaultRuleTarget || {};
    let globalInputStatus = true;
    // 内部值检验
    const innerCheckResult = value ? validatorInnerField(value, fieldType) : true;
    if (!innerCheckResult) {
        return {
            fieldState: innerCheckResult,
            validatorType: 'inner',
        };
    }
    // 自定义校验
    if (typeof customRuleFun === 'function') {
        // 由于form item memo，rule里面的函数拿不到外部的值，提供getFieldValue函数，后续修改memo逻辑
        return {
            fieldState: customRuleFun(value, {
                getFieldValue,
            }),
            validatorType: 'custom',
        };
    }
    // rule校验 - 取两者皆不存在的反 - 任意一个存在
    if (!(!require && !pattern)) {
        let result = true;
        if ([null, undefined, ''].includes(value)) {
            result = false;
        }
        globalInputStatus = pattern ? pattern.test(value) : result;
    }
    return {
        fieldState: globalInputStatus,
        validatorType: 'rule',
    };
};
const validatorStyleInner = (type, value) => {
    let str = '';
    switch (type) {
        case 'inputNumber':
            str = validatorIntegerText(value);
            break;
        case 'inputDigit':
            str = validatorDigitText(value);
            break;
        default:
            break;
    }
    return [errorCss, str];
};
const validatorStyle = (validatorType, type, value, rule) => {
    var _a, _b;
    switch (validatorType) {
        case 'custom':
            return [errorCss, validatorRequireText(((_a = rule[0]) === null || _a === void 0 ? void 0 : _a.message) || '')];
        case 'inner':
            return validatorStyleInner(type, value);
        case 'rule':
            return [errorCss, validatorRequireText(((_b = rule[0]) === null || _b === void 0 ? void 0 : _b.message) || '')];
        default:
            return [errorCss, ''];
    }
};
const validatorField = (rule, value, fieldType, getFieldValue) => {
    if (typeof value === 'undefined')
        return [normalCss, ''];
    const { fieldState, validatorType } = validatorRule(rule, value, fieldType, getFieldValue);
    if (fieldState) {
        // 兼容下item里面的处理
        return [normalCss, ''];
    }
    return validatorStyle(validatorType, fieldType, value, rule);
};
export default validatorField;
//# sourceMappingURL=index.js.map