import get from 'lodash/get';
import set from 'lodash/set';
import unset from 'lodash/unset';
import { toArray, getErrorTarget, toString } from '../util';
class FormStore {
    constructor() {
        this.getFieldsValue = () => this.store;
        this.resetStore = () => {
            const restTarget = Object.keys(this.store).reduce((pre, cur) => (Object.assign(Object.assign({}, pre), { [cur]: undefined })), {});
            this.updateStore(restTarget);
            this.notifywatchList();
        };
        this.store = {};
        /**
         * name - key
         * onStoreChange - 更新方法
         * rules - 规则
         */
        this.watchList = [];
        this.callbacks = {
            onFinish() { },
            onFinishFailed() { },
            onValuesChange() { },
            onReset() { },
        };
        this.pendingUnset = [];
        this.timer = undefined;
    }
    registerWatch(field) {
        this.watchList.push(field);
        return () => {
            this.watchList = this.watchList.filter((e) => e !== field);
        };
    }
    getFieldValue(name) {
        // undefined来区分首次
        return get(this.store, toArray(name), undefined);
    }
    removeFieldValue(name) {
        this.pendingUnset.push(toArray(name));
        window.clearTimeout(this.timer);
        this.timer = window.setTimeout(() => {
            while (this.pendingUnset.length) {
                const cur = this.pendingUnset.pop();
                unset(this.store, cur);
                this.notifywatchList(cur);
            }
            const { onValuesChange } = this.callbacks;
            onValuesChange === null || onValuesChange === void 0 ? void 0 : onValuesChange({}, this.store);
        }, 30);
    }
    setFieldValue(name, value) {
        if (this.getFieldValue(name) !== value) {
            set(this.store, toArray(name), value);
            const { onValuesChange } = this.callbacks;
            onValuesChange === null || onValuesChange === void 0 ? void 0 : onValuesChange({ name, value }, this.store);
            this.notifywatchList(name);
        }
    }
    setFieldsValue(newStore) {
        const newStoreTarget = Object.assign(Object.assign({}, this.store), newStore);
        this.updateStore(newStoreTarget);
        const { onValuesChange } = this.callbacks;
        onValuesChange === null || onValuesChange === void 0 ? void 0 : onValuesChange({}, newStoreTarget);
        this.notifywatchList();
    }
    setCallbacks(callbacks) {
        this.callbacks = Object.assign(Object.assign({}, this.callbacks), callbacks);
    }
    notifywatchList(name) {
        this.watchList.forEach((field) => {
            const { onStoreChange } = field;
            if (name) {
                if (toString(name) === toString(field.name)) {
                    onStoreChange();
                }
            }
            else {
                onStoreChange();
            }
        });
    }
    async validatorFields() {
        const errorValiadtorArr = [];
        const valiadtorPromiseArr = this.watchList.map(({ validatorRules, name }) => { var _a; return validatorRules((_a = this.getFieldValue(name)) !== null && _a !== void 0 ? _a : ''); });
        const allRes = await Promise.all(valiadtorPromiseArr);
        if (!Array.isArray(allRes))
            throw new Error(allRes);
        allRes.forEach(({ state, name }) => !state &&
            errorValiadtorArr.push({
                name,
                value: this.getFieldValue(name),
            }));
        if (!errorValiadtorArr.length)
            return this.getFieldsValue();
        const { name, value } = errorValiadtorArr[0];
        throw new Error(JSON.stringify({ [name]: value }));
    }
    updateStore(nextStore) {
        this.store = nextStore;
    }
    async submit() {
        const { onFinish, onFinishFailed } = this.callbacks;
        this.validatorFields()
            .then((res) => onFinish(res))
            .catch((err) => {
            const valiadtorErroTarget = getErrorTarget(err);
            onFinishFailed(valiadtorErroTarget || {});
            this.watchList.forEach(({ setSubmitTotal }) => setSubmitTotal && setSubmitTotal((pre) => pre + 1));
        });
    }
    async reset() {
        const { onReset } = this.callbacks;
        try {
            this.resetStore();
            const arr = this.watchList.map(({ validatorRules }) => validatorRules(undefined));
            await Promise.all(arr);
            onReset();
        }
        catch (error) { }
    }
    getForm() {
        return {
            removeFieldValue: this.removeFieldValue.bind(this),
            getFieldValue: this.getFieldValue.bind(this),
            getFieldsValue: this.getFieldsValue.bind(this),
            setFieldsValue: this.setFieldsValue.bind(this),
            setFieldValue: this.setFieldValue.bind(this),
            validatorFields: this.validatorFields.bind(this),
            setCallbacks: this.setCallbacks.bind(this),
            registerWatch: this.registerWatch.bind(this),
            submit: this.submit.bind(this),
            reset: this.reset.bind(this),
        };
    }
}
export default FormStore;
//# sourceMappingURL=index.js.map