var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React, { useEffect, useMemo, useRef, useState } from 'react';
import cx from 'classnames';
import Taro from '@tarojs/taro';
import { ScrollView, View } from '@tarojs/components';
import { selectorQueryClientRect } from '../../utils';
import HuiIcon from '../Icon/Icon';
import HuiSticky from '../Sticky/Sticky';
const defaultProps = {
    onChange: () => undefined,
};
const HuiTabs = (props) => {
    const { active, scroll = false, animated = false, smile = false, hasSubTitle = false, shadow = true, onChange = defaultProps.onChange, indicatorColor = '', sticky = false, offsetTop = 0, children, style = {}, className = '' } = props, rest = __rest(props
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    , ["active", "scroll", "animated", "smile", "hasSubTitle", "shadow", "onChange", "indicatorColor", "sticky", "offsetTop", "children", "style", "className"]);
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    const tabsRef = useRef();
    const [tabsInfos, setTabsInfos] = useState([]);
    const [tabsWidth, setTabsWidth] = useState(0);
    const [tabs, setTabs] = useState([]);
    const [defaultTabInfo] = useState({
        width: 0,
        left: 0,
        tabsWrapperScrollLeft: 0,
    });
    const activeTabInfo = useMemo(() => {
        if (!tabs) {
            return defaultTabInfo;
        }
        let index = active;
        if (typeof active === 'string') {
            index = tabs.findIndex((t) => t.name === active);
        }
        const activeRes = tabsInfos[index];
        if (!activeRes) {
            return defaultTabInfo;
        }
        return {
            left: activeRes.left,
            width: activeRes.width,
            tabsWrapperScrollLeft: scroll && activeRes.left && activeRes.width && tabsWidth
                ? activeRes.left + activeRes.width / 2 - tabsWidth / 2
                : 0,
        };
    }, [active, defaultTabInfo, scroll, tabs, tabsInfos, tabsWidth]);
    useEffect(() => {
        Taro.nextTick(async () => {
            var _a, _b, _c, _d, _e, _f;
            if (tabs.length <= 0 || !tabsRef.current) {
                return;
            }
            const tabsItemEle = (_a = tabsRef.current) === null || _a === void 0 ? void 0 : _a.childNodes;
            const temp = [];
            for (let i = 0; tabsItemEle && i < tabsItemEle.length; i++) {
                if ((_c = (_b = tabsItemEle[i]) === null || _b === void 0 ? void 0 : _b.childNodes[0]) === null || _c === void 0 ? void 0 : _c.childNodes[0]) {
                    const childNode = tabsItemEle[i].childNodes[0].childNodes[0];
                    const childNodeId = hasSubTitle && ((_e = (_d = childNode === null || childNode === void 0 ? void 0 : childNode.childNodes) === null || _d === void 0 ? void 0 : _d[0]) === null || _e === void 0 ? void 0 : _e.uid)
                        ? (_f = childNode.childNodes[0]) === null || _f === void 0 ? void 0 : _f.uid : childNode === null || childNode === void 0 ? void 0 : childNode.uid;
                    const res = await selectorQueryClientRect(`#${childNodeId}`);
                    temp.push(res);
                }
            }
            const res = await selectorQueryClientRect(`#${tabsRef.current.uid}`);
            setTabsInfos(temp);
            setTabsWidth(res === null || res === void 0 ? void 0 : res.width);
        });
    }, [tabs, hasSubTitle]);
    const handleUpdateParent = (i) => (tabValue) => {
        setTabs((t) => {
            const newTab = t.slice();
            newTab[i] = tabValue;
            if (!newTab[i].name) {
                newTab[i].name = i;
            }
            return newTab;
        });
    };
    const handleClickTabs = (name) => {
        onChange(name);
    };
    const getChildren = () => {
        const fn = (child, index) => React.cloneElement(child, {
            updateParent: handleUpdateParent(index),
            name: child.props.name || index,
            active,
            animated,
        });
        return (children && React.Children.map(children, fn)) || null;
    };
    const tabsSize = React.Children.count(children);
    const getTabsIndicator = () => smile ? (React.createElement(View, { className: 'tabs-indicator-smile', style: {
            left: activeTabInfo.left + activeTabInfo.width / 2,
            color: indicatorColor,
        } },
        React.createElement(HuiIcon, { name: '010-choose', size: 18 }))) : (React.createElement(View, { className: 'tabs-indicator', style: {
            width: activeTabInfo.width,
            left: activeTabInfo.left,
            background: indicatorColor,
        } }));
    const getTabsItem = (tab) => hasSubTitle ? (React.createElement(View, { className: 'tabs-title-twin' },
        React.createElement(View, { className: 'title', style: { color: tab.name === active ? indicatorColor : '' } }, tab.title),
        React.createElement(View, { className: 'sub-title', style: { color: tab.name === active ? indicatorColor : '' } }, tab.subTitle))) : (React.createElement(View, { className: cx('tabs-title', {
            [`tabs-title-smile`]: smile,
        }) }, tab.title));
    const tabsContent = (React.createElement(View, { ref: tabsRef, className: cx('hui-tabs-wrapper', { scrollable: scroll }, { normal: !scroll }, { 'no-shadow': !shadow }) },
        tabs.map((tab) => (React.createElement(View, { key: `${tab.name}`, className: `tabs-item length-${tabsSize}`, onClick: () => handleClickTabs(tab.name) },
            React.createElement(View, { className: cx('tabs-item-wrapper', { active: active === tab.name }) }, getTabsItem(tab))))),
        getTabsIndicator()));
    const activeTabIndex = tabs.findIndex((t) => t.name === active);
    const huiTabsBar = (React.createElement(View, Object.assign({}, rest, { className: cx('hui-tabs-bar', { 'no-shadow': !shadow }) }), scroll ? (React.createElement(ScrollView, { enhanced: true, showScrollbar: false, scrollX: scroll, scrollLeft: activeTabInfo.tabsWrapperScrollLeft, scrollWithAnimation: true, className: 'scrollable-tabs-wrapper' }, tabsContent)) : (tabsContent)));
    return (React.createElement(View, { className: `hui-tabs ${className}`, style: style },
        sticky ? (React.createElement(HuiSticky, { offsetTop: offsetTop }, huiTabsBar)) : (huiTabsBar),
        React.createElement(View, { className: 'hui-tabs-panel-wrapper' },
            React.createElement(View, { className: cx('hui-tabs-panel', {
                    'switch-with-animation': animated,
                }), style: animated
                    ? { transform: `translateX(-${100 * activeTabIndex}%)` }
                    : {} }, getChildren()))));
};
export default HuiTabs;
//# sourceMappingURL=Tabs.js.map