import { ViewProps } from '@tarojs/components/types/View';
import React from 'react';
import './SelectBody.scss';
export interface HuiSelectOption {
    /** 选项名 */
    label: string;
    /** 选项值 */
    value: string | number;
    /** 是否禁用 */
    disabled?: boolean;
    /** 子选项 */
    children?: HuiSelectOption[];
}
declare type HuiSelectCustom = <T>(item: T, index?: number) => React.ReactNode;
export interface HuiSelectParentOption extends HuiSelectOption {
    /** 自定义 level 2 item */
    record?: HuiSelectCustom;
    /** 自定义 level 2 底部元素 */
    customBottom?: React.ReactNode;
}
export declare type Level = 1 | 2;
export declare type OptionValue<T extends number> = T extends 2 ? (string | number)[][] : (string | number)[];
export interface HuiSelectBodyProps extends ViewProps {
    /** 菜单层级，默认为2 */
    level?: Level;
    /** 是否支持多选, 默认为false，即单选 */
    multiSelect?: boolean;
    /** 是否展示徽标，level为2 且 multiSelect为true时生效 */
    showBadge?: boolean;
    /** 选项 */
    options: HuiSelectParentOption[];
    /**
     * 选中值
     * 一级菜单时为选中项的value
     * 二级菜单时为所有子选项的value
     * */
    value: OptionValue<Level>;
    /** 自定义 level 1 item */
    record?: HuiSelectCustom;
    /** 自定义 level 2 底部元素 */
    customBottom?: React.ReactNode;
    /** 主题色设置 */
    color?: string;
    /** 开启异步加载画面 */
    loading?: boolean;
    /** hui-select-body的高度，默认由内容撑开，可以选择设置 */
    contentHeight?: number;
    /** 是否需要全选 选项 只有在 multiSelect=true 时生效 */
    checkAll?: boolean;
    style?: React.CSSProperties;
    className?: string;
    /** 选中选项时的回调 */
    onChange?(v: OptionValue<Level>): void;
    /** level为2时，切换侧边菜单时的回调 */
    onChangeSideMenu?(v: number | string): void;
}
declare const SelectBody: React.FC<HuiSelectBodyProps>;
export default SelectBody;
